=== modified file 'setup.py'
--- setup.py	2008-01-21 06:02:46 +0000
+++ setup.py	2008-01-22 00:31:16 +0000
@@ -142,6 +142,10 @@
     except:
         ivle_install_dir = "/opt/ivle"
     try:
+        public_host = confmodule.public_host
+    except:
+        public_host = "public.localhost"
+    try:
         jail_base = confmodule.jail_base
     except:
         jail_base = "/home/informatics/jails"
@@ -149,6 +153,7 @@
     # Just set reasonable defaults
     root_dir = "/ivle"
     ivle_install_dir = "/opt/ivle"
+    public_host = "public.localhost"
     jail_base = "/home/informatics/jails"
 # Always defaults
 allowed_uids = "0"
@@ -262,6 +267,7 @@
 Args are:
     --root_dir
     --ivle_install_dir
+    --public_host
     --jail_base
     --allowed_uids
 As explained in the interactive prompt or conf.py.
@@ -376,7 +382,7 @@
         file.write(']\n')
 
 def conf(args):
-    global root_dir, ivle_install_dir, jail_base, allowed_uids
+    global root_dir, ivle_install_dir, jail_base, public_host, allowed_uids
     # Set up some variables
 
     cwd = os.getcwd()
@@ -417,6 +423,9 @@
         jail_base = query_user(jail_base,
         """Root directory where the jails (containing user files) are stored
 (on the local file system):""")
+        public_host = query_user(public_host,
+        """Hostname which will cause the server to go into "public mode",
+providing login-free access to student's published work:""")
         allowed_uids = query_user(allowed_uids,
         """UID of the web server process which will run IVLE.
 Only this user may execute the trampoline. May specify multiple users as
@@ -432,6 +441,8 @@
             ivle_install_dir = opts['--ivle_install_dir']
         if '--jail_base' in opts:
             jail_base = opts['--jail_base']
+        if '--public_host' in opts:
+            public_host = opts['--public_host']
         if '--allowed_uids' in opts:
             allowed_uids = opts['--allowed_uids']
 
@@ -463,11 +474,19 @@
 # This directory should contain the "www" and "bin" directories.
 ivle_install_dir = "%s"
 
+# The server goes into "public mode" if the browser sends a request with this
+# host. This is for security reasons - we only serve public student files on a
+# separate domain to the main IVLE site.
+# Public mode does not use cookies, and serves only public content.
+# Private mode (normal mode) requires login, and only serves files relevant to
+# the logged-in user.
+public_host = "%s"
+
 # In the local file system, where are the student/user file spaces located.
 # The user jails are expected to be located immediately in subdirectories of
 # this location.
 jail_base = "%s"
-""" % (root_dir, ivle_install_dir, jail_base))
+""" % (root_dir, ivle_install_dir, public_host, jail_base))
 
         conf.close()
     except IOError, (errno, strerror):

=== modified file 'www/conf/apps.py'
--- www/conf/apps.py	2008-01-14 00:55:05 +0000
+++ www/conf/apps.py	2008-01-22 00:31:16 +0000
@@ -31,6 +31,9 @@
 # Note that if this app requires authentication, the user will first be
 # presented with the login screen.
 default_app = "files"
+# Which application to use for "public host" URLs.
+# (See conf.py)
+public_app = "serve"
 
 # Application definitions
 

=== modified file 'www/dispatch/__init__.py'
--- www/dispatch/__init__.py	2008-01-12 12:37:53 +0000
+++ www/dispatch/__init__.py	2008-01-22 00:31:16 +0000
@@ -59,6 +59,14 @@
             # TODO: Nicer 404 message?
             req.throw_error(Request.HTTP_NOT_FOUND)
 
+    # Special handling for public mode - just call public app and get out
+    # NOTE: This will not behave correctly if the public app uses
+    # write_html_head_foot, but "serve" does not.
+    if req.publicmode:
+        app = conf.apps.app_url[conf.apps.public_app]
+        apps.call_app(app.dir, req)
+        return req.OK
+
     # app is the App object for the chosen app
     if req.app is None:
         app = conf.apps.app_url[conf.apps.default_app]

=== modified file 'www/dispatch/request.py'
--- www/dispatch/request.py	2008-01-21 05:47:23 +0000
+++ www/dispatch/request.py	2008-01-22 00:31:16 +0000
@@ -26,6 +26,7 @@
 import common.util
 import mod_python
 from mod_python import (util, Session)
+import conf
 
 class Request:
     """An IVLE request object. This is presented to the IVLE apps as a way of
@@ -51,6 +52,10 @@
             Table object representing headers sent by the client.
         headers_out (read, can be written to)
             Table object representing headers to be sent to the client.
+        publicmode (read)
+            Bool. True if the request came for the "public host" as
+            configured in conf.py. Note that public mode requests do not
+            have an app (app is set to None).
 
         status (write)
             Int. Response status number. Use one of the status codes defined
@@ -160,13 +165,24 @@
         self.func_write_html_head = write_html_head
         self.headers_written = False
 
+        # Determine if the browser used the public host name to make the
+        # request (in which case we are in "public mode")
+        if req.hostname == conf.public_host:
+            self.publicmode = True
+        else:
+            self.publicmode = False
+
         # Inherit values for the input members
         self.method = req.method
         self.uri = req.uri
         # Split the given path into the app (top-level dir) and sub-path
         # (after first stripping away the root directory)
-        (self.app, self.path) = (
-            common.util.split_path(common.util.unmake_path(req.uri)))
+        path = common.util.unmake_path(req.uri)
+        if self.publicmode:
+            self.app = None
+            self.path = path
+        else:
+            (self.app, self.path) = (common.util.split_path(path))
         self.username = None
         self.hostname = req.hostname
         self.headers_in = req.headers_in

